@@ -32,7 +32,7 @@ var config = {
     workConfigTemplatePath:function(){return this.templatePath() + "config/"},
     workRouterTemplatePath:function(){return path.join(this.templatePath() , "router/");},
     //workViewTemplatePath:function(){return path.join(this.templatePath() ,"view/",this.endName,"/");},
-    workControllerTemplatePath:function(){return path.join(this.templatePath() ,"view",this.endName, "/");},
+    workControllerTemplatePath:function(){return path.join(this.templatePath() ,"controller",this.endName, "/");},
     workModelTemplatePath:function(){return this.templatePath() + "model/"},
     workReduxTemplatePath:function(){return path.join(this.templatePath() , "redux/");},
     //workLayoutTemplatePath:function(){return this.templatePath() + "layout/"},
@@ -62,6 +62,7 @@ var config = {
     buildBaseParams: function(){
         return {
             appName: this.appName,
+            endName: this.endName,
             moduleName:this.module,
             apiServer:this.apiServer,
         };
